Skip to contents

Plot a differential-expression volcano plot

Usage

plot_de_volcano(
  result,
  coef = NULL,
  fdr = 0.05,
  min_abs_effect = 1,
  label_features = NULL,
  feature_labels = NULL,
  symmetric_x = TRUE
)

Arguments

result

Input accepted by de_table().

coef

Optional coefficient passed to de_table().

fdr

Maximum adjusted p-value.

min_abs_effect

Minimum absolute effect estimate.

label_features

Feature identifiers to label; no features are selected for labels automatically.

feature_labels

Optional complete feature-named labels or a named feature-label column in a data frame result.

symmetric_x

Centre the x axis on zero with equal negative and positive limits. Set to FALSE to use ggplot2's automatic x range.

Value

An unprinted standard ggplot object carrying recommended physical dimensions for plot_save().