The databases are distributed through Bioconductor ExperimentHub and are downloaded into its local cache when first requested. This function reports metadata only; it does not download a database.
The databases are distributed through Bioconductor ExperimentHub and are downloaded into its local cache when first requested. This function reports metadata only; it does not download a database.