Gene lengths may be supplied directly, read from one rowData column, or
read from an aligned assay such as the sample-specific effective-length
assay produced by import_tximport(). No external preprocessing step is
required.
Arguments
- x
A
MultiAssayExperimentobject.- experiment
Optional experiment name.
- lengths
A positive numeric vector, a feature-named numeric vector, a feature-by-sample matrix, or the name of a
rowDatacolumn or assay. WhenNULL, an assay namedlength(as produced byimport_tximport()) is used.- assay
Assay name or one-based assay index.