A compact, colour-blind-friendly theme used by the package's plotting
helpers. Its default text sizes are designed for the recommended physical
dimensions used by plot_save(). Add ordinary ggplot2 themes or scales to
a returned plot to replace any part of it.
Usage
theme_bulkmae(base_size = 6, base_family = "")
Arguments
- base_size
Base font size.
- base_family
Base font family.
Value
A ggplot2 theme object.
See also
Other plotting:
plot_assay_heatmap(),
plot_de_ma(),
plot_de_volcano(),
plot_embedding(),
plot_gsea_classic(),
plot_gsea_ridge(),
plot_ora_bubble(),
plot_ora_network(),
plot_ora_radial(),
plot_qc_correlation(),
plot_qc_library(),
plot_qc_outliers(),
plot_save()